##  Overview
The OData integration provides a read-only connector to export fact sheet data in the form of saved searches (also referred to as bookmarks) to business intelligence (BI) tools. This integration enhances your ad-hoc reporting capabilities, allowing you to take advantage of the extensive features that various BI tools offer. Because this is only a one-way integration, importing data back into your SAP LeanIX workspace is not possible.
You can configure the OData integration with the BI tool of your choice, such as Microsoft Power BI, Tableau, SAP Analytics Cloud, and more. To configure the integration, follow the steps described in this guide.
**Note**
The current integration supports OData version 4.
